(* Mathematica Test File for Madrigal web services *)

mlhServer = "http://madrigal.haystack.mit.edu/cgi-bin/madrigal";
eiscatServer = "http://www.eiscat.se/madrigal/cgi-bin/";
(* These fields required by getData[] below *)
name = "Your full name";
affil = "Your affiliation";
email = "Your email";


(* getInstruments *)
Test[
	Cases[getInstruments[mlhServer],{"Name"->"Jicamarca IS Radar",___},Infinity]
	,
	{{"Name" -> "Jicamarca IS Radar", "Code" -> 10, "Mnemonic" -> "jro", 
 	"Latitude" -> -11.95, "Longitude" -> 283.13, "Altitude" -> 0.525, 
 	"Type" -> "Incoherent Scatter Radars"}}
	,
	TestID->"Test-20120730-M7Z0M8"
]

(* getExperiments *)
Test[
	getExperiments[mlhServer,{1998,1,1,0,0,0},{1999,1,1},"Local"->False,"InstrumentCode"->30][[1]]
	,
	{"Id" -> 10000163, "Url" -> "http://madrigal.haystack.mit.edu/cgi-bin/madrigal/madtoc/experiments/1998/mlh/09may98g", 
		"Name" -> "Gridded ISR data", "SiteId" -> 1, "SiteName" -> "Millstone", "InstCode" -> 30, 
		"InstName" -> "Millstone Hill IS Radar", "Local" -> True, "PI" -> "Phil Erickson", 
		"ContactEmail" -> "perickson@haystack.mit.edu", "StartDate" -> {1998, 5, 9, 0, 0, 0}, 
		"EndDate" -> {1998, 5, 9, 20, 0, 0}}
  	,
	TestID->"Test-20120730-T8Q8C2"
]

(* getExperimentFiles *)
Test[
	getExperimentFiles[eiscatServer, 20001996][[1]]
	,
	{"Name" -> "/opt/madrigal/experiments/2011/lyr/04jan11/NCAR_2011-01-04_taro_60_42mc.bin", 
	 "Kindat" -> 6800, "KindatDescription" -> "GUISDAP Fitted Parameters", "Category" -> 1, 
	 "Status" -> "Final", "Permission" -> 0, "ExperimentId" -> 20001996}
	,
	TestID->"Test-20120730-M6H8P4"
]

(* getParameters *)
Test[
	getParameters[eiscatServer, "/opt/madrigal/experiments/2011/lyr/04jan11/NCAR_2011-01-04_taro_60_42mc.bin"][[1]]
	,
	{"Mnemonic" -> "AZM", 
 	 "Description" -> "Mean azimuth angle (0=geog N,90=east)", 
 	 "IsError" -> False, "Unit" -> "deg", "IsMeasured" -> True, 
 	 "Category" -> "Geographic Coordinate", "IsSure" -> True, 
 	 "IsAddIncrement" -> False}
 	,
	TestID->"Test-20120730-C2R0Q9"
]

(* getData (isprintService.py) *)
Test[
	getData[eiscatServer, "/opt/madrigal/experiments/2011/lyr/04jan11/NCAR_2011-01-04_taro_60_42mc.bin", 
		{"Date","Ti"}, name, affil, email][[1]]
	,
	{{2011, 1, 4, 8, 1, 44.}, 216.}
	,
	TestID->"Test-20120730-F6P1M9"
]

(* positionCalculator *)
Test[
	positionCalculator[mlhServer,{2000,1,1,0,0,0},{20,20,1},{40,40,1},{100,200,100},{"bn","be","bd"}]
	,
	{{20., 40., 100., 0.0000333234, 1.23496*^-6, 0.0000169369}, 
	 {20., 40., 200., 0.0000316262, 1.07698*^-6, 0.0000160164}}
	,
	TestID->"Test-20120730-J5N5L6"
]

(* timeCalculator *)
Test[
	timeCalculator[mlhServer,{2000,1,1},{2000,1,1,23,59,59},1,{"kp","f10.7"}][[1;;2]]
	,
	{{{2000, 1, 1, 0, 0, 0.}, 5.3, 1.299*10^-20},
	 {{2000, 1, 1, 1, 0, 0.}, 5.3, 1.299*10^-20}}
   	,
	TestID->"Test-20120730-E0D8X4"
]

(* radarToGeodetic *)
Test[
	radarToGeodetic[mlhServer, {42.619, 288.51, 0.146},{{100, 45, 1000}, {100, 55, 1000}, {100, 65, 1000}}]
	,
	{{41.361338,-64.012651,742.038442},
     {41.645771,-65.488196,841.794521},
     {41.932738,-67.098375,918.473216}}
	,
	TestID->"Test-20120730-Z0U4K2"
]

(* geodeticToRadar *)
Test[
	geodeticToRadar[mlhServer, {42.619, 288.51, 0.146},{{42, 290, 1000}, {42, 290, 2000}, {42, 290, 3000}}]
	,
  	{{117.704418,80.825093,1011.252383},
	 {116.906481,84.802395,2006.351074},
	 {116.270492,86.139493,3004.705956}}
	,
	TestID->"Test-20120730-T9X1K2"
]


(* traceMagneticField *)
Test[
	traceMagneticField[mlhServer,{2004,1,1},{{0.583,-0.95987,0.269},{0.6,-10.,0.3},{0.6,-1.,0.3},{0.6,-10.,0.3},{0.6,-1.,0.3}},
		 "InCoordinates"->"GSM","OutCoordinates"->"Geodetic","TargetLocation"->"NorthAlt","StopAlt"->1000.000000]
	,
	{{Missing[], Missing[], Missing[]},
	 {1000., 74.691608, 102.005302},
	 {1000., 19.026771, 129.44524},
	 {1000., 74.691608, 102.005302},
	 {1000., 19.026771, 129.44524}}
	,
	TestID->"Test-20120730-C3R9Q9"
]


(* getMetadata *)
Test[
	Cases[getMetaData[mlhServer,"FileType"->5],{1,___},Infinity]
	,
	{{1, "Millstone", "madrigal.haystack.mit.edu", "madrigal", "cgi-bin/madrigal", "madrigal/servlets", "Bill Rideout",
		 "MIT Haystack Observatory", "Route 40", "", "Westford", "MA", 1886, "USA", "1-781-981-5624", "brideout@haystack.mit.edu"}}
	,
	TestID->"Test-20120730-T4N3O4"
]


(* MadrigalWeb`Private`constructQuery *)

Test[
	MadrigalWeb`Private`constructServiceRequest["server","service",MadrigalWeb`Private`constructQueryList[{"name1","name2"},{1,2}]]
	,
	"server/service?name1=1&name2=2"
	,
	TestID->"Test-20120802-T0K6P9"
]

Test[
	MadrigalWeb`Private`dateQuery[{2012,8,2}]
	,
	{"year=2012", "month=8", "day=2", "hour=0", "min=0", "sec=0"}
	,
	TestID->"Test-20120802-R6M8U9"
]

