(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    120585,       2617]
NotebookOptionsPosition[    116962,       2488]
NotebookOutlinePosition[    117318,       2504]
CellTagsIndexPosition[    117275,       2501]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Setup", "Section",
 CellChangeTimes->{{3.5527902178494062`*^9, 3.552790218421027*^9}}],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<MadrigalWeb`\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.552954596346519*^9, 3.552954601698742*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
  "mlhServer", "=", 
   "\"\<http://madrigal.haystack.mit.edu/cgi-bin/madrigal\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "pfisrServer", "=", "\"\<http://isr.sri.com/madrigal/cgi-bin/\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "eiscatServer", "=", "\"\<http://www.eiscat.com/madrigal/cgi-bin/\>\""}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.5527846274415693`*^9, 3.5527846284449377`*^9}, {
  3.552925773675457*^9, 3.552925780324891*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Instruments", "Section",
 CellChangeTimes->{{3.552790221668922*^9, 3.55279022311651*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"instruments", "=", 
   RowBox[{"getInstruments", "[", "mlhServer", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.552790039953933*^9, 3.5527900470274353`*^9}, {
   3.552925785866938*^9, 3.552925788514542*^9}, 3.5529546098027277`*^9}],

Cell["Here is a list of the first 25 instruments in the database.", "Text",
 CellChangeTimes->{{3.552790230445381*^9, 3.552790246220275*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Style", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<Name\>\"", ",", "\"\<Code\>\""}], "}"}], "/.", 
     RowBox[{"instruments", "[", 
      RowBox[{"[", 
       RowBox[{"1", ";;", "25"}], "]"}], "]"}]}], "//", "TableForm"}], ",", 
   "Small"}], "]"}]], "Input",
 CellChangeTimes->{{3.5527847601638308`*^9, 3.552784768347851*^9}, {
  3.5527878193854933`*^9, 3.5527878553039007`*^9}, {3.552790045904163*^9, 
  3.552790082731247*^9}, {3.5529257926433277`*^9, 3.552925793179778*^9}}],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"Jicamarca IS Radar\"\>", "10"},
     {"\<\"Jicamarca Bistatic Radar\"\>", "11"},
     {"\<\"Arecibo IS Radar - Linefeed\"\>", "20"},
     {"\<\"Arecibo IS Radar - Gregorian\"\>", "21"},
     {"\<\"Arecibo IS Radar - Velocity Vector\"\>", "22"},
     {"\<\"MU IS Radar\"\>", "25"},
     {"\<\"Millstone Hill IS Radar\"\>", "30"},
     {"\<\"Millstone Hill UHF Steerable Antenna\"\>", "31"},
     {"\<\"Millstone Hill UHF Zenith Antenna\"\>", "32"},
     {"\<\"St. Santin IS Radar\"\>", "40"},
     {"\<\"St. Santin Nan\[CCedilla]ay Receiver\"\>", "41"},
     {"\<\"St. Santin Mende Receiver\"\>", "42"},
     {"\<\"St. Santin Monpazier Receiver\"\>", "43"},
     {"\<\"Kharkov Ukraine IS Radar\"\>", "45"},
     {"\<\"Chatanika IS Radar\"\>", "50"},
     {"\<\"ISTP Irkutsk Radar\"\>", "53"},
     {"\<\"Poker Flat IS Radar\"\>", "61"},
     {"\<\"EISCAT combined IS Radars\"\>", "70"},
     {"\<\"EISCAT Kiruna UHF IS Receiver\"\>", "71"},
     {"\<\"EISCAT Tromso UHF IS radar\"\>", "72"},
     {"\<\"EISCAT Sodankyla UHF IS Receiver\"\>", "73"},
     {"\<\"EISCAT Tromso VHF IS radar\"\>", "74"},
     {"\<\"Sondrestrom IS Radar\"\>", "80"},
     {"\<\"Resolute Bay North IS Radar\"\>", "91"},
     {"\<\"EISCAT Svalbard IS Radar Longyearbyen\"\>", "95"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$]]],
  StripOnInput->False,
  FontSize->Small]], "Output",
 CellChangeTimes->{{3.552790056978375*^9, 3.552790083143306*^9}, 
   3.5529257936409893`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Experiments", "Section",
 CellChangeTimes->{{3.552790251059763*^9, 3.552790252859631*^9}}],

Cell["\<\
Get all the experiments run on RISR-N between 2005 and today:\
\>", "Text",
 CellChangeTimes->{{3.552790258171926*^9, 3.5527903024081287`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"res", "=", 
   RowBox[{"getExperiments", "[", 
    RowBox[{"mlhServer", ",", 
     RowBox[{"{", 
      RowBox[{"2005", ",", "1", ",", "1"}], "}"}], ",", 
     RowBox[{"DateList", "[", "]"}], ",", 
     RowBox[{"\"\<Local\>\"", "\[Rule]", "False"}], ",", 
     RowBox[{"\"\<InstrumentCode\>\"", "\[Rule]", "91"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.552786758503921*^9, 3.552786790257135*^9}, {
   3.552787253887439*^9, 3.552787264439232*^9}, {3.5527873218620253`*^9, 
   3.552787345653351*^9}, {3.5527885256511183`*^9, 3.552788543570566*^9}, {
   3.55278916006919*^9, 3.552789190515587*^9}, 3.552789531555937*^9, {
   3.552790100635477*^9, 3.55279012528266*^9}, {3.552790305141864*^9, 
   3.552790307105257*^9}, {3.552925797547736*^9, 3.55292579981153*^9}, 
   3.5529546168837337`*^9}],

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"res", "[", 
     RowBox[{"[", "n", "]"}], "]"}], "//", "TableForm"}], ",", 
   RowBox[{"{", 
    RowBox[{"n", ",", "1", ",", 
     RowBox[{"Length", "@", "res"}], ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.552788582943179*^9, 3.552788583199917*^9}, {
  3.5527886720628757`*^9, 3.552788685063816*^9}}],

Cell["\<\
The Joule-2 rocket mission experiments (Joule-2 launched on 19 January 2007). \
Try January 2007:\
\>", "Text",
 CellChangeTimes->{{3.5527903519718943`*^9, 3.552790404192408*^9}, {
  3.552790575827114*^9, 3.552790583266706*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"joule2", "=", 
  RowBox[{"getExperiments", "[", 
   RowBox[{"mlhServer", ",", 
    RowBox[{"{", 
     RowBox[{"2007", ",", "1", ",", "1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"2007", ",", "2", ",", "1"}], "}"}], ",", 
    RowBox[{"\"\<InstrumentCode\>\"", "\[Rule]", "61"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.55279036532323*^9, 3.5527904982792253`*^9}, {
   3.552790560710023*^9, 3.552790586596925*^9}, {3.552925807923685*^9, 
   3.5529258087630577`*^9}, 3.5529546238342867`*^9}],

Cell[BoxData[
 RowBox[{"{", "}"}]], "Output",
 CellChangeTimes->{3.552790593733395*^9, 3.5529233213723717`*^9, 
  3.552925815473214*^9}]
}, Open  ]],

Cell["\<\
It\[CloseCurlyQuote]s not in the database during January 2007. There is a \
\[OpenCurlyDoubleQuote]Joule2\[CloseCurlyDoubleQuote] experiment, but it ran \
on March 1st:\
\>", "Text",
 CellChangeTimes->{{3.552790596660469*^9, 3.5527906093699923`*^9}, {
  3.5527909219217052`*^9, 3.552790942496943*^9}, {3.552969668907997*^9, 
  3.552969682138955*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"year2007", "=", 
   RowBox[{"getExperiments", "[", 
    RowBox[{"mlhServer", ",", 
     RowBox[{"{", "2007", "}"}], ",", 
     RowBox[{"{", "2008", "}"}], ",", 
     RowBox[{"\"\<InstrumentCode\>\"", "\[Rule]", "61"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.552790639615726*^9, 3.5527906700104847`*^9}, {
   3.552925813802799*^9, 3.552925818018641*^9}, 3.552954629267003*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Pane", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Sort", "@", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"DateString", "[", 
           RowBox[{"#", ",", 
            RowBox[{"{", 
             RowBox[{
             "\"\<Year\>\"", ",", "\"\<Month\>\"", ",", "\"\<Day\>\""}], 
             "}"}]}], "]"}], "&"}], "/@", 
         RowBox[{"(", 
          RowBox[{"\"\<StartDate\>\"", "/.", "year2007"}], ")"}]}], ",", 
        RowBox[{"\"\<Id\>\"", "/.", "year2007"}], ",", 
        RowBox[{"\"\<Name\>\"", "/.", "year2007"}], ",", 
        RowBox[{"\"\<Url\>\"", "/.", "year2007"}]}], "}"}], "]"}]}], "//", 
    "TableForm"}], ",", 
   RowBox[{"Scrollbars", "\[Rule]", "True"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"450", ",", "200"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.552790773249576*^9, 3.552790867198778*^9}, {
  3.5527911235951157`*^9, 3.5527911533050737`*^9}, {3.552791198130278*^9, 
  3.5527912382944593`*^9}, {3.5529232878267117`*^9, 3.552923293902598*^9}, {
  3.5529234054662123`*^9, 3.5529234115702477`*^9}}],

Cell[BoxData[
 PaneBox[
  TagBox[GridBox[{
     {"\<\"20070301\"\>", 
      "30001373", "\<\"IPY01 - Long duration measurements in support of the \
International Polar Year\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/01mar07c\
\"\>"},
     {"\<\"20070301\"\>", 
      "30001374", "\<\"Joule2 - Auroral and convection measurements\"\>", "\<\
\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/01mar07m\"\>\
"},
     {"\<\"20070318\"\>", 
      "30001444", "\<\"WorldDay02 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/18mar07a\
\"\>"},
     {"\<\"20070319\"\>", 
      "30001449", "\<\"WorldDay02 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/19mar07a\
\"\>"},
     {"\<\"20070321\"\>", 
      "30001453", "\<\"WorldDay02 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/21mar07a\
\"\>"},
     {"\<\"20070327\"\>", 
      "30001472", "\<\"WorldDay02 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/27mar07d\
\"\>"},
     {"\<\"20070401\"\>", 
      "30001368", "\<\"IPY01 - Long duration measurements in support of the \
International Polar Year\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/01apr07a\
\"\>"},
     {"\<\"20070428\"\>", 
      "30001474", "\<\"WorldDay02 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/28apr07a\
\"\>"},
     {"\<\"20070501\"\>", 
      "30001375", "\<\"IPY01 - Long duration measurements in support of the \
International Polar Year\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/01may07a\
\"\>"},
     {"\<\"20070501\"\>", 
      "30001376", "\<\"WorldDay02 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/01may07b\
\"\>"},
     {"\<\"20070502\"\>", 
      "30001382", "\<\"WorldDay02 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/02may07a\
\"\>"},
     {"\<\"20070503\"\>", 
      "30001386", "\<\"WorldDay02 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/03may07a\
\"\>"},
     {"\<\"20070504\"\>", 
      "30001390", "\<\"WorldDay02 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/04may07b\
\"\>"},
     {"\<\"20070516\"\>", 
      "30001438", "\<\"WorldDay02 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/16may07a\
\"\>"},
     {"\<\"20070517\"\>", 
      "30001443", "\<\"WorldDay02 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/17may07a\
\"\>"},
     {"\<\"20070521\"\>", 
      "30001454", "\<\"WorldDay02 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/21may07b\
\"\>"},
     {"\<\"20070522\"\>", 
      "30001460", "\<\"WorldDay02 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/22may07b\
\"\>"},
     {"\<\"20070526\"\>", 
      "30001469", "\<\"WorldDay02 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/26may07a\
\"\>"},
     {"\<\"20070527\"\>", 
      "30001473", "\<\"WorldDay02 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/27may07a\
\"\>"},
     {"\<\"20070529\"\>", 
      "30001479", "\<\"Sporadic02 - Thin layer and imaging mode\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/29may07a\
\"\>"},
     {"\<\"20070601\"\>", 
      "30001372", "\<\"IPY01 - Long duration measurements in support of the \
International Polar Year\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/01jun07a\
\"\>"},
     {"\<\"20070605\"\>", 
      "30001394", "\<\"Sporadic02 - Thin layer and imaging mode\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/05jun07b\
\"\>"},
     {"\<\"20070611\"\>", 
      "30001414", "\<\"Sporadic02 - Thin layer and imaging mode\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/11jun07a\
\"\>"},
     {"\<\"20070612\"\>", 
      "30001419", "\<\"Lyons01 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/12jun07b\
\"\>"},
     {"\<\"20070617\"\>", 
      "30001442", "\<\"Lyons01 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/17jun07a\
\"\>"},
     {"\<\"20070619\"\>", 
      "30001448", "\<\"WorldDay02 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/19jun07m\
\"\>"},
     {"\<\"20070623\"\>", 
      "30001462", "\<\"Lyons01 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/23jun07a\
\"\>"},
     {"\<\"20070628\"\>", 
      "30001477", "\<\"Lyons01 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/28jun07a\
\"\>"},
     {"\<\"20070703\"\>", 
      "30001385", "\<\"IPY01 - Long duration measurements in support of the \
International Polar Year\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/03jul07b\
\"\>"},
     {"\<\"20070712\"\>", 
      "30001418", "\<\"Sporadic02 - Thin layer and imaging mode\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/12jul07c\
\"\>"},
     {"\<\"20070714\"\>", 
      "30001432", "\<\"Lyons01 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/14jul07b\
\"\>"},
     {"\<\"20070719\"\>", 
      "30001446", "\<\"Lyons01 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/19jul07a\
\"\>"},
     {"\<\"20070719\"\>", 
      "30001447", "\<\"WorldDay02 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/19jul07e\
\"\>"},
     {"\<\"20070724\"\>", 
      "30001464", "\<\"Sporadic02 - Thin layer and imaging mode\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/24jul07a\
\"\>"},
     {"\<\"20070725\"\>", 
      "30001465", "\<\"Lyons01 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/25jul07a\
\"\>"},
     {"\<\"20070727\"\>", 
      "30001471", "\<\"Sporadic02 - Thin layer and imaging mode\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/27jul07f\
\"\>"},
     {"\<\"20070729\"\>", 
      "30001478", "\<\"Sporadic02 - Thin layer and imaging mode\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/29jul07a\
\"\>"},
     {"\<\"20070730\"\>", 
      "30001483", "\<\"Sporadic02 - Thin layer and imaging mode\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/30jul07a\
\"\>"},
     {"\<\"20070731\"\>", 
      "30001486", "\<\"Sporadic02 - Thin layer and imaging mode\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/31jul07a\
\"\>"},
     {"\<\"20070801\"\>", 
      "30001369", "\<\"WorldDay02 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/01aug07a\
\"\>"},
     {"\<\"20070801\"\>", 
      "30001370", "\<\"IPY01 - Long duration measurements in support of the \
International Polar Year\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/01aug07c\
\"\>"},
     {"\<\"20070802\"\>", 
      "30001380", "\<\"WorldDay02 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/02aug07a\
\"\>"},
     {"\<\"20070802\"\>", 
      "30001381", "\<\"WorldDay02 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/02aug07c\
\"\>"},
     {"\<\"20070804\"\>", 
      "30001387", "\<\"WorldDay02 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/04aug07a\
\"\>"},
     {"\<\"20070805\"\>", 
      "30001392", "\<\"WorldDay02 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/05aug07a\
\"\>"},
     {"\<\"20070806\"\>", 
      "30001395", "\<\"WorldDay02 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/06aug07a\
\"\>"},
     {"\<\"20070807\"\>", 
      "30001398", "\<\"WorldDay02 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/07aug07a\
\"\>"},
     {"\<\"20070808\"\>", 
      "30001400", "\<\"Sporadic02 - Thin layer and imaging mode\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/08aug07a\
\"\>"},
     {"\<\"20070809\"\>", 
      "30001404", "\<\"Sporadic02 - Thin layer and imaging mode\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/09aug07a\
\"\>"},
     {"\<\"20070810\"\>", 
      "30001410", "\<\"Sporadic02 - Thin layer and imaging mode\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/10aug07b\
\"\>"},
     {"\<\"20070811\"\>", 
      "30001412", "\<\"Sporadic02 - Thin layer and imaging mode\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/11aug07a\
\"\>"},
     {"\<\"20070812\"\>", 
      "30001416", "\<\"Sporadic02 - Thin layer and imaging mode\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/12aug07a\
\"\>"},
     {"\<\"20070813\"\>", 
      "30001423", "\<\"Sporadic02 - Thin layer and imaging mode\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/13aug07a\
\"\>"},
     {"\<\"20070814\"\>", 
      "30001428", "\<\"Sporadic02 - Thin layer and imaging mode\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/14aug07a\
\"\>"},
     {"\<\"20070814\"\>", 
      "30001429", "\<\"IPY02 - Long duration measurements in support of the \
International Polar Year\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/14aug07c\
\"\>"},
     {"\<\"20070815\"\>", 
      "30001435", "\<\"Sporadic02 - Thin layer and imaging mode\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/15aug07a\
\"\>"},
     {"\<\"20070816\"\>", 
      "30001436", "\<\"WorldDay02 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/16aug07c\
\"\>"},
     {"\<\"20070817\"\>", 
      "30001440", "\<\"Lyons01 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/17aug07a\
\"\>"},
     {"\<\"20070817\"\>", 
      "30001441", "\<\"WorldDay02 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/17aug07b\
\"\>"},
     {"\<\"20070822\"\>", 
      "30001455", "\<\"Watkins01 -\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/22aug07b\
\"\>"},
     {"\<\"20070822\"\>", 
      "30001456", "\<\"Lyons01 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/22aug07d\
\"\>"},
     {"\<\"20070822\"\>", 
      "30001457", "\<\"Sporadic02 - Thin layer and imaging mode\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/22aug07e\
\"\>"},
     {"\<\"20070822\"\>", 
      "30001458", "\<\"Sporadic02 - Thin layer and imaging mode\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/22aug07g\
\"\>"},
     {"\<\"20070822\"\>", 
      "30001459", "\<\"Sporadic02 - Thin layer and imaging mode\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/22aug07i\
\"\>"},
     {"\<\"20070823\"\>", 
      "30001461", "\<\"Watkins01 -\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/23aug07b\
\"\>"},
     {"\<\"20070827\"\>", 
      "30001470", "\<\"Lyons01 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/27aug07a\
\"\>"},
     {"\<\"20070830\"\>", 
      "30001481", "\<\"Sporadic02 - Thin layer and imaging mode\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/30aug07a\
\"\>"},
     {"\<\"20070830\"\>", 
      "30001482", "\<\"WorldDay02 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/30aug07c\
\"\>"},
     {"\<\"20070901\"\>", 
      "30001378", "\<\"Lyons01 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/01sep07a\
\"\>"},
     {"\<\"20070901\"\>", 
      "30001379", "\<\"IPY02 - Long duration measurements in support of the \
International Polar Year\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/01sep07b\
\"\>"},
     {"\<\"20070902\"\>", 
      "30001384", "\<\"Sporadic02 - Thin layer and imaging mode\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/02sep07a\
\"\>"},
     {"\<\"20070904\"\>", 
      "30001391", "\<\"Sporadic02 - Thin layer and imaging mode\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/04sep07b\
\"\>"},
     {"\<\"20070907\"\>", 
      "30001399", "\<\"Lyons01 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/07sep07b\
\"\>"},
     {"\<\"20070911\"\>", 
      "30001415", "\<\"WorldDay02 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/11sep07a\
\"\>"},
     {"\<\"20070912\"\>", 
      "30001421", "\<\"Lyons01 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/12sep07a\
\"\>"},
     {"\<\"20070912\"\>", 
      "30001422", "\<\"WorldDay02 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/12sep07b\
\"\>"},
     {"\<\"20070913\"\>", 
      "30001427", "\<\"WorldDay02 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/13sep07d\
\"\>"},
     {"\<\"20070914\"\>", 
      "30001434", "\<\"WorldDay02 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/14sep07b\
\"\>"},
     {"\<\"20071008\"\>", 
      "30001426", "\<\"IPY04 - Long duration measurements in support of the \
International Polar Year\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/13oct07m\
\"\>"},
     {"\<\"20071012\"\>", 
      "30001420", "\<\"WorldDay03 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/12oct07a\
\"\>"},
     {"\<\"20071016\"\>", 
      "30001439", "\<\"Sporadic03 - Thin layer and imaging mode\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/16oct07a\
\"\>"},
     {"\<\"20071018\"\>", 
      "30001445", "\<\"Sporadic03 - Thin layer and imaging mode\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/18oct07a\
\"\>"},
     {"\<\"20071019\"\>", 
      "30001451", "\<\"Lyons02 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/19oct07a\
\"\>"},
     {"\<\"20071025\"\>", 
      "30001467", "\<\"WorldDay03 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/25oct07a\
\"\>"},
     {"\<\"20071029\"\>", 
      "30001480", "\<\"Lyons02 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/29oct07a\
\"\>"},
     {"\<\"20071030\"\>", 
      "30001485", "\<\"Lyons02 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/30oct07b\
\"\>"},
     {"\<\"20071101\"\>", 
      "30001377", "\<\"Sporadic03 - Thin layer and imaging mode\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/01nov07a\
\"\>"},
     {"\<\"20071102\"\>", 
      "30001383", "\<\"IPY04 - Long duration measurements in support of the \
International Polar Year\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/02nov07a\
\"\>"},
     {"\<\"20071108\"\>", 
      "30001402", "\<\"Watkins02 -\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/08nov07b\
\"\>"},
     {"\<\"20071108\"\>", 
      "30001403", "\<\"WorldDay03 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/08nov07e\
\"\>"},
     {"\<\"20071109\"\>", 
      "30001408", "\<\"Lyons02 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/09nov07a\
\"\>"},
     {"\<\"20071109\"\>", 
      "30001409", "\<\"WorldDay03 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/09nov07b\
\"\>"},
     {"\<\"20071113\"\>", 
      "30001425", "\<\"Watkins02 -\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/13nov07b\
\"\>"},
     {"\<\"20071114\"\>", 
      "30001433", "\<\"Lyons02 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/14nov07b\
\"\>"},
     {"\<\"20071119\"\>", 
      "30001450", "\<\"Lyons02 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/19nov07a\
\"\>"},
     {"\<\"20071120\"\>", 
      "30001452", "\<\"WorldDay03 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/20nov07a\
\"\>"},
     {"\<\"20071125\"\>", 
      "30001466", "\<\"Lyons02 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/25nov07a\
\"\>"},
     {"\<\"20071130\"\>", 
      "30001484", "\<\"Lyons02 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/30nov07a\
\"\>"},
     {"\<\"20071201\"\>", 
      "30001371", "\<\"IPY04 - Long duration measurements in support of the \
International Polar Year\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/01dec07a\
\"\>"},
     {"\<\"20071204\"\>", 
      "30001388", "\<\"WorldDay03 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/04dec07a\
\"\>"},
     {"\<\"20071204\"\>", 
      "30001389", "\<\"Watkins02 -\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/04dec07c\
\"\>"},
     {"\<\"20071205\"\>", 
      "30001393", "\<\"WorldDay03 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/05dec07a\
\"\>"},
     {"\<\"20071206\"\>", 
      "30001396", "\<\"WorldDay03 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/06dec07a\
\"\>"},
     {"\<\"20071206\"\>", 
      "30001397", "\<\"WorldDay03 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/06dec07e\
\"\>"},
     {"\<\"20071208\"\>", 
      "30001401", "\<\"Lyons02 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/08dec07a\
\"\>"},
     {"\<\"20071209\"\>", 
      "30001405", "\<\"WorldDay03 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/09dec07a\
\"\>"},
     {"\<\"20071209\"\>", 
      "30001406", "\<\"Watkins02 -\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/09dec07b\
\"\>"},
     {"\<\"20071209\"\>", 
      "30001407", "\<\"LTCS01 - Electric field and E region wind measurements\
\"\>", "\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/\
09dec07f\"\>"},
     {"\<\"20071210\"\>", 
      "30001411", "\<\"WorldDay03 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/10dec07a\
\"\>"},
     {"\<\"20071211\"\>", 
      "30001413", "\<\"WorldDay03 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/11dec07a\
\"\>"},
     {"\<\"20071212\"\>", 
      "30001417", "\<\"Lyons02 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/12dec07a\
\"\>"},
     {"\<\"20071213\"\>", 
      "30001424", "\<\"WorldDay03 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/13dec07b\
\"\>"},
     {"\<\"20071214\"\>", 
      "30001430", "\<\"WorldDay03 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/14dec07a\
\"\>"},
     {"\<\"20071214\"\>", 
      "30001431", "\<\"Watkins02 -\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/14dec07b\
\"\>"},
     {"\<\"20071216\"\>", 
      "30001437", "\<\"Lyons02 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/16dec07a\
\"\>"},
     {"\<\"20071224\"\>", 
      "30001463", "\<\"Lyons02 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/24dec07a\
\"\>"},
     {"\<\"20071226\"\>", 
      "30001468", "\<\"Lyons02 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/26dec07a\
\"\>"},
     {"\<\"20071228\"\>", 
      "30001475", "\<\"Lyons02 - Auroral and convection measurements\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/28dec07a\
\"\>"},
     {"\<\"20071228\"\>", 
      "30001476", "\<\"Sporadic03 - Thin layer and imaging mode\"\>", \
"\<\"http://isr.sri.com/madrigal/cgi-bin/madtoc/experiments/2007/pfa/28dec07c\
\"\>"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$]]],
  ImageSize->{450, 200},
  ScrollPosition->{735., 0.},
  Scrollbars->True]], "Output",
 CellChangeTimes->{{3.552790855752572*^9, 3.55279086764995*^9}, {
   3.552791131014401*^9, 3.552791153864668*^9}, {3.552791199705143*^9, 
   3.552791238848878*^9}, 3.552923296617693*^9, 3.5529233310428333`*^9, 
   3.5529234121055*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Experiment Files", "Section",
 CellChangeTimes->{{3.5529232133602867`*^9, 3.5529232159019012`*^9}}],

Cell[BoxData[
 RowBox[{"<<", "\"\<MadrigalWeb`\>\""}]], "Input",
 CellChangeTimes->{{3.5529232502079697`*^9, 3.552923259320765*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"results", "=", 
   RowBox[{"getExperimentFiles", "[", 
    RowBox[{"pfisrServer", ",", "30001374"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.552923218543077*^9, 3.552923231536504*^9}, {
   3.552923262090639*^9, 3.552923270930855*^9}, 3.5529233407759123`*^9, {
   3.552923449272449*^9, 3.552923450643343*^9}, 3.552923706026602*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"results", "[", 
   RowBox[{"[", "1", "]"}], "]"}], "//", "TableForm"}]], "Input",
 CellChangeTimes->{{3.552923709913261*^9, 3.552923717633876*^9}}],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      RowBox[{"\<\"Name\"\>", 
       "\[Rule]", \
"\<\"/opt/madrigal/experiments/2007/pfa/01mar07m/pfa070301.001\"\>"}]},
     {
      RowBox[{"\<\"Kindat\"\>", "\[Rule]", "5962"}]},
     {
      RowBox[{"\<\"KindatDescription\"\>", 
       "\[Rule]", "\<\"Alternating Code Uncorrected Ne\"\>"}]},
     {
      RowBox[{"\<\"Category\"\>", "\[Rule]", "1"}]},
     {
      RowBox[{"\<\"Status\"\>", "\[Rule]", "\<\"Final\"\>"}]},
     {
      RowBox[{"\<\"Permission\"\>", "\[Rule]", "0"}]},
     {
      RowBox[{"\<\"ExperimentId\"\>", "\[Rule]", "30001374"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.5599999999999999]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   Column],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.552923712121743*^9, 3.552923718098752*^9}, 
   3.552924171578012*^9, 3.552924278324786*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"getExperimentFiles", "[", 
    RowBox[{"eiscatServer", ",", "20001996"}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], "//", "TableForm"}]], "Input",
 CellChangeTimes->{{3.552924720919598*^9, 3.5529247209210997`*^9}, {
  3.552925678940679*^9, 3.552925696196124*^9}, {3.55292574011595*^9, 
  3.5529257408818197`*^9}}],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      RowBox[{"\<\"Name\"\>", 
       "\[Rule]", \
"\<\"/opt/madrigal/experiments/2011/lyr/04jan11/NCAR_2011-01-04_taro_60_42mc.\
bin\"\>"}]},
     {
      RowBox[{"\<\"Kindat\"\>", "\[Rule]", "6800"}]},
     {
      RowBox[{"\<\"KindatDescription\"\>", 
       "\[Rule]", "\<\"GUISDAP Fitted Parameters\"\>"}]},
     {
      RowBox[{"\<\"Category\"\>", "\[Rule]", "1"}]},
     {
      RowBox[{"\<\"Status\"\>", "\[Rule]", "\<\"Final\"\>"}]},
     {
      RowBox[{"\<\"Permission\"\>", "\[Rule]", "0"}]},
     {
      RowBox[{"\<\"ExperimentId\"\>", "\[Rule]", "20001996"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.5599999999999999]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   Column],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.552925688213252*^9, 3.552925698055863*^9}, 
   3.552925742906328*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Parameters", "Section",
 CellChangeTimes->{{3.552925836474812*^9, 3.5529258378472443`*^9}, {
  3.552951913541353*^9, 3.5529519212151833`*^9}}],

Cell[BoxData[
 RowBox[{"<<", "\"\<MadrigalWeb`\>\""}]], "Input",
 CellChangeTimes->{{3.5529232502079697`*^9, 3.552923259320765*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"params", "=", 
   RowBox[{"getParameters", "[", 
    RowBox[{
    "eiscatServer", ",", 
     "\"\</opt/madrigal/experiments/2011/lyr/04jan11/NCAR_2011-01-04_taro_60_\
42mc.bin\>\""}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.552925887036626*^9, 3.5529259041452703`*^9}, {
  3.552925964889001*^9, 3.55292596768804*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"params", "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5529484199722233`*^9, 3.5529484215208187`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\<\"Mnemonic\"\>", "\[Rule]", "\<\"AZM\"\>"}], ",", 
   RowBox[{"\<\"Description\"\>", 
    "\[Rule]", "\<\"Mean azimuth angle (0=geog N,90=east)\"\>"}], ",", 
   RowBox[{"\<\"IsError\"\>", "\[Rule]", "False"}], ",", 
   RowBox[{"\<\"Unit\"\>", "\[Rule]", "\<\"deg\"\>"}], ",", 
   RowBox[{"\<\"IsMeasured\"\>", "\[Rule]", "True"}], ",", 
   RowBox[{"\<\"Category\"\>", "\[Rule]", "\<\"Geographic Coordinate\"\>"}], 
   ",", 
   RowBox[{"\<\"IsSure\"\>", "\[Rule]", "True"}], ",", 
   RowBox[{"\<\"IsAddIncrement\"\>", "\[Rule]", "False"}]}], "}"}]], "Output",\

 CellChangeTimes->{3.552948421929203*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Data", "Section",
 CellChangeTimes->{{3.5529519234615593`*^9, 3.552951923921521*^9}}],

Cell["\<\
getData[...] is equivalent to isprintService.py. Replace the name, \
affiliation and email parameters below with your details. You can request \
\[OpenCurlyDoubleQuote]Date\[CloseCurlyDoubleQuote] instead of the usual \
\[OpenCurlyDoubleQuote]year\[CloseCurlyDoubleQuote], \
\[OpenCurlyDoubleQuote]month\[CloseCurlyDoubleQuote], \
\[OpenCurlyDoubleQuote]day\[CloseCurlyDoubleQuote], etc., time parameters to \
get a DateList[] for each entry.\
\>", "Text",
 CellChangeTimes->{{3.552954930358214*^9, 3.5529549521955843`*^9}, {
  3.5529555171829576`*^9, 3.552955625362836*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
  "file", "=", 
   "\"\</opt/madrigal/experiments/2011/lyr/04jan11/NCAR_2011-01-04_taro_60_\
42mc.bin\>\""}], ";"}]], "Input",
 CellChangeTimes->{{3.552951951960021*^9, 3.552951953535421*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"getData", "[", 
    RowBox[{"eiscatServer", ",", "file", ",", 
     RowBox[{"{", 
      RowBox[{
      "\"\<Date\>\"", ",", "\"\<Gdlat\>\"", ",", "\"\<Glon\>\"", ",", 
       "\"\<Gdalt\>\"", ",", "\"\<Ti\>\""}], "}"}], ",", "\"\<Your name\>\"", 
     ",", "\"\<Your affiliation\>\"", ",", "\"\<Your email address\>\""}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.552953388871902*^9, 3.552953399506879*^9}, {
  3.5529535986845083`*^9, 3.552953605683043*^9}, {3.552953966716937*^9, 
  3.5529539676603527`*^9}, {3.552954005227777*^9, 3.55295400728166*^9}, {
  3.552954280537136*^9, 3.55295428151024*^9}, {3.552955491302064*^9, 
  3.552955509463726*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "@", "data"}]], "Input",
 CellChangeTimes->{{3.552954349768346*^9, 3.55295435221915*^9}}],

Cell[BoxData["54534"], "Output",
 CellChangeTimes->{3.552954352635044*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DateListPlot", "[", 
  RowBox[{
   RowBox[{"data", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "5"}], "}"}]}], "]"}], "]"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Time (UT)\>\"", ",", 
      "\"\<\!\(\*SubscriptBox[\(T\), \(i\)]\) (K)\>\""}], "}"}]}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<EISCAT 2011/01/04\>\""}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5529543535623207`*^9, 3.552954524389229*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, 
   {Hue[0.67, 0.6, 0.6], PointBox[CompressedData["
1:eJyF3XtwXNd9H/A7rZrBNGqLpmxn67CZjaJxYFvjWUtyzFi0tSJlCbJpCqQo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     "]]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  AxesOrigin->{3.503117*^9, 0},
  Frame->True,
  FrameLabel->{
    FormBox["\"Time (UT)\"", TraditionalForm], 
    FormBox[
    "\"\\!\\(\\*SubscriptBox[\\(T\\), \\(i\\)]\\) (K)\"", TraditionalForm]},
  FrameTicks->{{Automatic, Automatic}, {{{
       NCache[3503116800, 3.5031168*^9], 
       FormBox["\"08:00\"", TraditionalForm], {0.020601132958329826`, 0}}, {
       NCache[3503120400, 3.5031204*^9], 
       FormBox["\"09:00\"", TraditionalForm], {0.020601132958329826`, 0}}, {
       NCache[3503124000, 3.503124*^9], 
       FormBox["\"10:00\"", TraditionalForm], {0.020601132958329826`, 0}}, {
       NCache[3503117700, 3.5031177*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3503118600, 3.5031186*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3503119500, 3.5031195*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3503121300, 3.5031213*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3503122200, 3.5031222*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3503123100, 3.5031231*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3503124900, 3.5031249*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3503125800, 3.5031258*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}}, {{
       NCache[3503116800, 3.5031168*^9], 
       FormBox["\"\"", TraditionalForm], {0.020601132958329826`, 0}}, {
       NCache[3503120400, 3.5031204*^9], 
       FormBox["\"\"", TraditionalForm], {0.020601132958329826`, 0}}, {
       NCache[3503124000, 3.503124*^9], 
       FormBox["\"\"", TraditionalForm], {0.020601132958329826`, 0}}, {
       NCache[3503117700, 3.5031177*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3503118600, 3.5031186*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3503119500, 3.5031195*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3503121300, 3.5031213*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3503122200, 3.5031222*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3503123100, 3.5031231*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3503124900, 3.5031249*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}, {
       NCache[3503125800, 3.5031258*^9], 
       FormBox["\"\"", TraditionalForm], {0.012360679774997897`, 0}}}}},
  GridLines->NCache[{{{3503116800, 
       GrayLevel[0.8]}, {3503120400, 
       GrayLevel[0.8]}, {3503124000, 
       GrayLevel[0.8]}}, None}, {{{3.5031168*^9, 
       GrayLevel[0.8]}, {3.5031204*^9, 
       GrayLevel[0.8]}, {3.503124*^9, 
       GrayLevel[0.8]}}, None}],
  PlotLabel->FormBox["\"EISCAT 2011/01/04\"", TraditionalForm],
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic},
  Ticks->None]], "Output",
 CellChangeTimes->{{3.552954369185318*^9, 3.552954455756444*^9}, 
   3.5529545311247807`*^9},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Histogram", "[", 
  RowBox[{
   RowBox[{"data", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "5"}], "]"}], "]"}], ",", 
   RowBox[{"{", "25", "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "2500"}], "}"}], ",", "Automatic"}], "}"}]}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(T\), \(i\)]\) (K)\>\"", ",", 
      "\"\<Counts\>\""}], "}"}]}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"PlotRangeClipping", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.552954978885919*^9, 3.5529551092471457`*^9}, {
  3.552955175670767*^9, 3.5529552416436367`*^9}}],

Cell[BoxData[
 GraphicsBox[
  {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
   EdgeForm[Opacity[0.7]], {}, 
   {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
    EdgeForm[Opacity[0.7]], RectangleBox[{0., 0.}, {25., 299.},
     RoundingRadius->0], RectangleBox[{25., 0.}, {50., 122.},
     RoundingRadius->0], RectangleBox[{50., 0.}, {75., 102.},
     RoundingRadius->0], RectangleBox[{75., 0.}, {100., 120.},
     RoundingRadius->0], RectangleBox[{100., 0.}, {125., 115.},
     RoundingRadius->0], RectangleBox[{125., 0.}, {150., 120.},
     RoundingRadius->0], RectangleBox[{150., 0.}, {175., 103.},
     RoundingRadius->0], RectangleBox[{175., 0.}, {200., 105.},
     RoundingRadius->0], RectangleBox[{200., 0.}, {225., 570.},
     RoundingRadius->0], RectangleBox[{225., 0.}, {250., 130.},
     RoundingRadius->0], RectangleBox[{250., 0.}, {275., 99.},
     RoundingRadius->0], RectangleBox[{275., 0.}, {300., 105.},
     RoundingRadius->0], RectangleBox[{300., 0.}, {325., 96.},
     RoundingRadius->0], RectangleBox[{325., 0.}, {350., 98.},
     RoundingRadius->0], RectangleBox[{350., 0.}, {375., 101.},
     RoundingRadius->0], RectangleBox[{375., 0.}, {400., 99.},
     RoundingRadius->0], RectangleBox[{400., 0.}, {425., 110.},
     RoundingRadius->0], RectangleBox[{425., 0.}, {450., 74.},
     RoundingRadius->0], RectangleBox[{450., 0.}, {475., 77.},
     RoundingRadius->0], RectangleBox[{475., 0.}, {500., 72.},
     RoundingRadius->0], RectangleBox[{500., 0.}, {525., 87.},
     RoundingRadius->0], RectangleBox[{525., 0.}, {550., 73.},
     RoundingRadius->0], RectangleBox[{550., 0.}, {575., 67.},
     RoundingRadius->0], RectangleBox[{575., 0.}, {600., 68.},
     RoundingRadius->0], RectangleBox[{600., 0.}, {625., 57.},
     RoundingRadius->0], RectangleBox[{625., 0.}, {650., 59.},
     RoundingRadius->0], RectangleBox[{650., 0.}, {675., 64.},
     RoundingRadius->0], RectangleBox[{675., 0.}, {700., 50.},
     RoundingRadius->0], RectangleBox[{700., 0.}, {725., 52.},
     RoundingRadius->0], RectangleBox[{725., 0.}, {750., 55.},
     RoundingRadius->0], RectangleBox[{750., 0.}, {775., 65.},
     RoundingRadius->0], RectangleBox[{775., 0.}, {800., 40.},
     RoundingRadius->0], RectangleBox[{800., 0.}, {825., 45.},
     RoundingRadius->0], RectangleBox[{825., 0.}, {850., 57.},
     RoundingRadius->0], RectangleBox[{850., 0.}, {875., 43.},
     RoundingRadius->0], RectangleBox[{875., 0.}, {900., 44.},
     RoundingRadius->0], RectangleBox[{900., 0.}, {925., 35.},
     RoundingRadius->0], RectangleBox[{925., 0.}, {950., 37.},
     RoundingRadius->0], RectangleBox[{950., 0.}, {975., 39.},
     RoundingRadius->0], RectangleBox[{975., 0.}, {1000., 40.},
     RoundingRadius->0], RectangleBox[{1000., 0.}, {1025., 28.},
     RoundingRadius->0], RectangleBox[{1025., 0.}, {1050., 26.},
     RoundingRadius->0], RectangleBox[{1050., 0.}, {1075., 33.},
     RoundingRadius->0], RectangleBox[{1075., 0.}, {1100., 27.},
     RoundingRadius->0], RectangleBox[{1100., 0.}, {1125., 22.},
     RoundingRadius->0], RectangleBox[{1125., 0.}, {1150., 28.},
     RoundingRadius->0], RectangleBox[{1150., 0.}, {1175., 17.},
     RoundingRadius->0], RectangleBox[{1175., 0.}, {1200., 21.},
     RoundingRadius->0], RectangleBox[{1200., 0.}, {1225., 20.},
     RoundingRadius->0], RectangleBox[{1225., 0.}, {1250., 14.},
     RoundingRadius->0], RectangleBox[{1250., 0.}, {1275., 14.},
     RoundingRadius->0], RectangleBox[{1275., 0.}, {1300., 14.},
     RoundingRadius->0], RectangleBox[{1300., 0.}, {1325., 8.},
     RoundingRadius->0], RectangleBox[{1325., 0.}, {1350., 9.},
     RoundingRadius->0], RectangleBox[{1350., 0.}, {1375., 13.},
     RoundingRadius->0], RectangleBox[{1375., 0.}, {1400., 14.},
     RoundingRadius->0], RectangleBox[{1400., 0.}, {1425., 16.},
     RoundingRadius->0], RectangleBox[{1425., 0.}, {1450., 13.},
     RoundingRadius->0], RectangleBox[{1450., 0.}, {1475., 7.},
     RoundingRadius->0], RectangleBox[{1475., 0.}, {1500., 9.},
     RoundingRadius->0], RectangleBox[{1500., 0.}, {1525., 11.},
     RoundingRadius->0], RectangleBox[{1525., 0.}, {1550., 10.},
     RoundingRadius->0], RectangleBox[{1550., 0.}, {1575., 8.},
     RoundingRadius->0], RectangleBox[{1575., 0.}, {1600., 6.},
     RoundingRadius->0], RectangleBox[{1600., 0.}, {1625., 10.},
     RoundingRadius->0], RectangleBox[{1625., 0.}, {1650., 6.},
     RoundingRadius->0], RectangleBox[{1650., 0.}, {1675., 7.},
     RoundingRadius->0], RectangleBox[{1675., 0.}, {1700., 10.},
     RoundingRadius->0], RectangleBox[{1700., 0.}, {1725., 5.},
     RoundingRadius->0], RectangleBox[{1725., 0.}, {1750., 6.},
     RoundingRadius->0], RectangleBox[{1750., 0.}, {1775., 5.},
     RoundingRadius->0], RectangleBox[{1775., 0.}, {1800., 2.},
     RoundingRadius->0], RectangleBox[{1800., 0.}, {1825., 8.},
     RoundingRadius->0], RectangleBox[{1825., 0.}, {1850., 9.},
     RoundingRadius->0], RectangleBox[{1850., 0.}, {1875., 6.},
     RoundingRadius->0], RectangleBox[{1875., 0.}, {1900., 4.},
     RoundingRadius->0], RectangleBox[{1900., 0.}, {1925., 2.},
     RoundingRadius->0], RectangleBox[{1925., 0.}, {1950., 5.},
     RoundingRadius->0], RectangleBox[{1950., 0.}, {1975., 4.},
     RoundingRadius->0], RectangleBox[{1975., 0.}, {2000., 6.},
     RoundingRadius->0], RectangleBox[{2000., 0.}, {2025., 8.},
     RoundingRadius->0], RectangleBox[{2025., 0.}, {2050., 8.},
     RoundingRadius->0], RectangleBox[{2050., 0.}, {2075., 4.},
     RoundingRadius->0], RectangleBox[{2075., 0.}, {2100., 5.},
     RoundingRadius->0], RectangleBox[{2100., 0.}, {2125., 5.},
     RoundingRadius->0], RectangleBox[{2125., 0.}, {2150., 5.},
     RoundingRadius->0], RectangleBox[{2150., 0.}, {2175., 8.},
     RoundingRadius->0], RectangleBox[{2175., 0.}, {2200., 3.},
     RoundingRadius->0], RectangleBox[{2200., 0.}, {2225., 4.},
     RoundingRadius->0], RectangleBox[{2225., 0.}, {2250., 3.},
     RoundingRadius->0], RectangleBox[{2250., 0.}, {2275., 3.},
     RoundingRadius->0], RectangleBox[{2275., 0.}, {2300., 3.},
     RoundingRadius->0], RectangleBox[{2300., 0.}, {2325., 6.},
     RoundingRadius->0], RectangleBox[{2325., 0.}, {2350., 1.},
     RoundingRadius->0], RectangleBox[{2350., 0.}, {2375., 2.},
     RoundingRadius->0], RectangleBox[{2375., 0.}, {2400., 3.},
     RoundingRadius->0], RectangleBox[{2400., 0.}, {2425., 1.},
     RoundingRadius->0], RectangleBox[{2425., 0.}, {2450., 1.},
     RoundingRadius->0], RectangleBox[{2450., 0.}, {2475., 1.},
     RoundingRadius->0], RectangleBox[{2475., 0.}, {2500., 1.},
     RoundingRadius->0], RectangleBox[{2500., 0.}, {2525., 2.},
     RoundingRadius->0], RectangleBox[{2525., 0.}, {2550., 4.},
     RoundingRadius->0], RectangleBox[{2550., 0.}, {2575., 3.},
     RoundingRadius->0], RectangleBox[{2575., 0.}, {2600., 4.},
     RoundingRadius->0], RectangleBox[{2600., 0.}, {2625., 1.},
     RoundingRadius->0], RectangleBox[{2625., 0.}, {2650., 2.},
     RoundingRadius->0], RectangleBox[{2650., 0.}, {2675., 2.},
     RoundingRadius->0], RectangleBox[{2675., 0.}, {2700., 3.},
     RoundingRadius->0], RectangleBox[{2700., 0.}, {2725., 2.},
     RoundingRadius->0], RectangleBox[{2725., 0.}, {2750., 1.},
     RoundingRadius->0], RectangleBox[{2750., 0.}, {2775., 1.},
     RoundingRadius->0], RectangleBox[{2775., 0.}, {2800., 1.},
     RoundingRadius->0], RectangleBox[{2800., 0.}, {2825., 2.},
     RoundingRadius->0], RectangleBox[{2825., 0.}, {2850., 1.},
     RoundingRadius->0], RectangleBox[{2850., 0.}, {2875., 1.},
     RoundingRadius->0], RectangleBox[{2875., 0.}, {2900., 1.},
     RoundingRadius->0], {}, RectangleBox[{2925., 0.}, {2950., 1.},
     RoundingRadius->0], RectangleBox[{2950., 0.}, {2975., 1.},
     RoundingRadius->0], {}, RectangleBox[{3000., 0.}, {3025., 1.},
     RoundingRadius->0], RectangleBox[{3025., 0.}, {3050., 1.},
     RoundingRadius->0], RectangleBox[{3050., 0.}, {3075., 1.},
     RoundingRadius->0], RectangleBox[{3075., 0.}, {3100., 1.},
     RoundingRadius->0], {}, RectangleBox[{3125., 0.}, {3150., 2.},
     RoundingRadius->0], RectangleBox[{3150., 0.}, {3175., 1.},
     RoundingRadius->0], RectangleBox[{3175., 0.}, {3200., 3.},
     RoundingRadius->0], {}, RectangleBox[{3225., 0.}, {3250., 2.},
     RoundingRadius->0], RectangleBox[{3250., 0.}, {3275., 1.},
     RoundingRadius->0], RectangleBox[{3275., 0.}, {3300., 1.},
     RoundingRadius->0], RectangleBox[{3300., 0.}, {3325., 1.},
     RoundingRadius->0], RectangleBox[{3325., 0.}, {3350., 1.},
     RoundingRadius->0], {}, {}, RectangleBox[{3400., 0.}, {3425., 2.},
     RoundingRadius->0], {}, RectangleBox[{3450., 0.}, {3475., 1.},
     RoundingRadius->0], {}, RectangleBox[{3500., 0.}, {3525., 2.},
     RoundingRadius->0], {}, {}, {}, {}, 
    RectangleBox[{3625., 0.}, {3650., 3.},
     RoundingRadius->0], {}, RectangleBox[{3675., 0.}, {3700., 4.},
     RoundingRadius->0], RectangleBox[{3700., 0.}, {3725., 1.},
     RoundingRadius->0], {}, RectangleBox[{3750., 0.}, {3775., 2.},
     RoundingRadius->0], {}, {}, {}, RectangleBox[{3850., 0.}, {3875., 1.},
     RoundingRadius->0], {}, RectangleBox[{3900., 0.}, {3925., 1.},
     RoundingRadius->0], {}, RectangleBox[{3950., 0.}, {3975., 1.},
     RoundingRadius->0], {}, {}, RectangleBox[{4025., 0.}, {4050., 1.},
     RoundingRadius->0], {}, {}, RectangleBox[{4100., 0.}, {4125., 1.},
     RoundingRadius->0], {}, {}, {}, RectangleBox[{4200., 0.}, {4225., 1.},
     RoundingRadius->0], {}, {}, RectangleBox[{4275., 0.}, {4300., 1.},
     RoundingRadius->0], {}, RectangleBox[{4325., 0.}, {4350., 1.},
     RoundingRadius->0], {}, RectangleBox[{4375., 0.}, {4400., 1.},
     RoundingRadius->0], RectangleBox[{4400., 0.}, {4425., 1.},
     RoundingRadius->0], {}, {}, {}, {}, {}, {}, {}, {}, {}, 
    RectangleBox[{4650., 0.}, {4675., 1.},
     RoundingRadius->0], {}, RectangleBox[{4700., 0.}, {4725., 1.},
     RoundingRadius->0], {}, RectangleBox[{4750., 0.}, {4775., 1.},
     RoundingRadius->0], {}, RectangleBox[{4800., 0.}, {4825., 1.},
     RoundingRadius->0], RectangleBox[{4825., 0.}, {4850., 2.},
     RoundingRadius->0], {}, {}, {}, {}, {}, {}, {}, {}, {}, 
    RectangleBox[{5075., 0.}, {5100., 1.},
     RoundingRadius->0], {}, {}, {}, {}, {}, 
    RectangleBox[{5225., 0.}, {5250., 1.},
     RoundingRadius->0], {}, {}, RectangleBox[{5300., 0.}, {5325., 1.},
     RoundingRadius->0], {}, {}, {}, {}, {}, {}, {}, {}, {}, 
    RectangleBox[{5550., 0.}, {5575., 1.},
     RoundingRadius->0], {}, {}, {}, {}, {}, {}, {}, {}, 
    RectangleBox[{5775., 0.}, {5800., 1.},
     RoundingRadius->0], RectangleBox[{5800., 0.}, {5825., 1.},
     RoundingRadius->0], {}, RectangleBox[{5850., 0.}, {5875., 1.},
     RoundingRadius->0], {}, {}, {}, {}, {}, 
    RectangleBox[{6000., 0.}, {6025., 2.},
     RoundingRadius->0], RectangleBox[{6025., 0.}, {6050., 1.},
     RoundingRadius->0], {}, {}, {}, {}, {}, {}, {}, {}, 
    RectangleBox[{6250., 0.}, {6275., 1.},
     RoundingRadius->0], RectangleBox[{6275., 0.}, {6300., 1.},
     RoundingRadius->0], {}, {}, {}, {}, 
    RectangleBox[{6400., 0.}, {6425., 1.},
     RoundingRadius->0], RectangleBox[{6425., 0.}, {6450., 1.},
     RoundingRadius->0], {}, {}, {}, {}, {}, {}, 
    RectangleBox[{6600., 0.}, {6625., 1.},
     RoundingRadius->0], {}, {}, {}, {}, {}, {}, 
    RectangleBox[{6775., 0.}, {6800., 1.},
     RoundingRadius->0], {}, {}, RectangleBox[{6850., 0.}, {6875., 1.},
     RoundingRadius->0], {}, {}, {}, {}, 
    RectangleBox[{6975., 0.}, {7000., 1.},
     RoundingRadius->0], RectangleBox[{7000., 0.}, {7025., 1.},
     RoundingRadius->0], {}, RectangleBox[{7050., 0.}, {7075., 1.},
     RoundingRadius->0], {}, {}, {}, {}, {}, {}, {}, 
    RectangleBox[{7250., 0.}, {7275., 1.},
     RoundingRadius->0], {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, 
    RectangleBox[{7550., 0.}, {7575., 1.},
     RoundingRadius->
      0], {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, RectangleBox[{8025., 0.}, {8050., 1.},
     RoundingRadius->0], {}, {}, RectangleBox[{8100., 0.}, {8125., 1.},
     RoundingRadius->0], {}, {}, {}, {}, {}, {}, {}, 
    RectangleBox[{8300., 0.}, {8325., 1.},
     RoundingRadius->0], {}, {}, {}, RectangleBox[{8400., 0.}, {8425., 1.},
     RoundingRadius->0], {}, RectangleBox[{8450., 0.}, {8475., 2.},
     RoundingRadius->
      0], {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, 
    RectangleBox[{8850., 0.}, {8875., 2.},
     RoundingRadius->0], {}, {}, RectangleBox[{8925., 0.}, {8950., 1.},
     RoundingRadius->0], {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, 
    RectangleBox[{9225., 0.}, {9250., 1.},
     RoundingRadius->0], {}, {}, {}, {}, {}, 
    RectangleBox[{9375., 0.}, {9400., 1.},
     RoundingRadius->0], {}, {}, {}, {}, 
    RectangleBox[{9500., 0.}, {9525., 1.},
     RoundingRadius->
      0], {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, RectangleBox[{9975., 0.}, {10000., 1.},
     RoundingRadius->0], {}, {}, {}, {}, {}, 
    RectangleBox[{10125., 0.}, {10150., 1.},
     RoundingRadius->
      0], {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, 
    RectangleBox[{11000., 0.}, {11025., 1.},
     RoundingRadius->
      0], {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, 
    RectangleBox[{11450., 0.}, {11475., 1.},
     RoundingRadius->0]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesOrigin->{0., 0},
  Frame->True,
  FrameLabel->{
    FormBox[
    "\"\\!\\(\\*SubscriptBox[\\(T\\), \\(i\\)]\\) (K)\"", TraditionalForm], 
    FormBox["\"Counts\"", TraditionalForm]},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  PlotRange->{{0, 2500}, {All, All}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {
     Scaled[0.02], 
     Scaled[0.1]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.552954999845181*^9, {3.552955034769449*^9, 3.552955062145978*^9}, {
   3.5529550972452393`*^9, 3.552955113450685*^9}, {3.55295521109147*^9, 
   3.5529552446886997`*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Position Calculator", "Section",
 CellChangeTimes->{{3.552961401602582*^9, 3.5529614041200047`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"positionCalculator", "[", 
   RowBox[{"mlhServer", ",", 
    RowBox[{"{", 
     RowBox[{"2000", ",", "1", ",", "1", ",", "0", ",", "0", ",", "0"}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"20", ",", "20", ",", "1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"40", ",", "40", ",", "1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"100", ",", "1000", ",", "100"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\"\<bn\>\"", ",", "\"\<be\>\"", ",", "\"\<bd\>\""}], "}"}]}], 
   "]"}], "//", "TableForm"}]], "Input",
 CellChangeTimes->{{3.552961422600349*^9, 3.5529614234460163`*^9}, {
  3.55296152258451*^9, 3.552961525676856*^9}, {3.5529615983509083`*^9, 
  3.5529616004782887`*^9}, {3.5529616929148808`*^9, 3.552961713858899*^9}, {
  3.552962748045205*^9, 3.5529627572205153`*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {"20.`", "40.`", "100.`", "0.0000333234`", "1.23496`*^-6", 
     "0.0000169369`"},
    {"20.`", "40.`", "200.`", "0.0000316262`", "1.07698`*^-6", 
     "0.0000160164`"},
    {"20.`", "40.`", "300.`", "0.0000300452`", "9.35348`*^-7", 
     "0.0000151675`"},
    {"20.`", "40.`", "400.`", "0.0000285704`", "8.08212`*^-7", 
     "0.0000143829`"},
    {"20.`", "40.`", "500.`", "0.0000271929`", "6.93945`*^-7", 
     "0.0000136562`"},
    {"20.`", "40.`", "600.`", "0.0000259046`", "5.91137`*^-7", 
     "0.0000129818`"},
    {"20.`", "40.`", "700.`", "0.0000246983`", "4.98556`*^-7", 
     "0.0000123547`"},
    {"20.`", "40.`", "800.`", "0.0000235674`", "4.15122`*^-7", 
     "0.0000117707`"},
    {"20.`", "40.`", "900.`", "0.0000225061`", "3.39887`*^-7", 
     "0.0000112258`"},
    {"20.`", "40.`", "1000.`", "0.0000215089`", "2.72013`*^-7", 
     "0.0000107166`"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.55296275058013*^9, 3.552962758038459*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Time Calculator", "Section",
 CellChangeTimes->{{3.552961401602582*^9, 3.5529614041200047`*^9}, {
  3.552962771171979*^9, 3.5529627715278883`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"results", "=", 
   RowBox[{"timeCalculator", "[", 
    RowBox[{"mlhServer", ",", 
     RowBox[{"{", 
      RowBox[{"2000", ",", "1", ",", "1", ",", "0", ",", "0", ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2000", ",", "1", ",", "1", ",", "23", ",", "59", ",", "59"}], 
      "}"}], ",", "1", ",", 
     RowBox[{"{", 
      RowBox[{"\"\<Kp\>\"", ",", "\"\<F10.7\>\""}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.552961422600349*^9, 3.5529614234460163`*^9}, {
   3.55296152258451*^9, 3.552961525676856*^9}, {3.5529615983509083`*^9, 
   3.5529616004782887`*^9}, {3.5529616929148808`*^9, 3.552961713858899*^9}, {
   3.552962748045205*^9, 3.552962809699358*^9}, {3.552962981365634*^9, 
   3.55296299492487*^9}, {3.552963129823757*^9, 3.552963153486745*^9}, 
   3.5529632979135303`*^9, {3.552963393134849*^9, 3.552963397957662*^9}, 
   3.552963445916679*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"results", "[", 
  RowBox[{"[", 
   RowBox[{"1", ";;", "2"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.552963520095149*^9, 3.552963526087929*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2000", ",", "1", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "5.3`", ",", "1.299`*^-20"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2000", ",", "1", ",", "1", ",", "1", ",", "0", ",", "0.`"}], 
      "}"}], ",", "5.3`", ",", "1.299`*^-20"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.552963522219632*^9, 3.552963526486146*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DateListPlot", "[", 
  RowBox[{
   RowBox[{"results", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2"}], "}"}]}], "]"}], "]"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<Kp\>\""}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5529634030159883`*^9, 3.552963427524235*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, 
   {Hue[0.67, 0.6, 0.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGCQAGIQDQQOP5qeOxqDgagDSPgXKv/Ib1R+218g/+wZEBAC
8T3+o/K5GJtR+GeYgHyIVQIgfh8LKj+ADZUvxAHkp4EBF4h/hROVP40blR/B
2wxznyCIL8WPyr8jgMqfJwS3jwPETxBB5SuJofKfiKPqXyaJys+QRuVryQL5
s2aCAC+I/0YOlb9OAYkPAAHnbYc=
     "]]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  AxesOrigin->NCache[{3155673600, 3.}, {3.1556736*^9, 3.}],
  Frame->True,
  FrameTicks->{{Automatic, Automatic}, {{{
       NCache[3155673600, 3.1556736*^9], 
       FormBox["\"00:00\"", TraditionalForm]}, {
       NCache[3155695200, 3.1556952*^9], 
       FormBox["\"06:00\"", TraditionalForm]}, {
       NCache[3155716800, 3.1557168*^9], 
       FormBox["\"12:00\"", TraditionalForm]}, {
       NCache[3155738400, 3.1557384*^9], 
       FormBox["\"18:00\"", TraditionalForm]}, {
       NCache[3155760000, 3.15576*^9], 
       FormBox["\"00:00\"", TraditionalForm]}, {
       NCache[3155680800, 3.1556808*^9], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[3155688000, 3.155688*^9], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[3155702400, 3.1557024*^9], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[3155709600, 3.1557096*^9], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[3155724000, 3.155724*^9], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[3155731200, 3.1557312*^9], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[3155745600, 3.1557456*^9], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[3155752800, 3.1557528*^9], 
       FormBox["\"\"", TraditionalForm]}}, {{
       NCache[3155673600, 3.1556736*^9], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[3155695200, 3.1556952*^9], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[3155716800, 3.1557168*^9], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[3155738400, 3.1557384*^9], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[3155760000, 3.15576*^9], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[3155680800, 3.1556808*^9], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[3155688000, 3.155688*^9], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[3155702400, 3.1557024*^9], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[3155709600, 3.1557096*^9], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[3155724000, 3.155724*^9], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[3155731200, 3.1557312*^9], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[3155745600, 3.1557456*^9], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[3155752800, 3.1557528*^9], 
       FormBox["\"\"", TraditionalForm]}}}},
  GridLines->NCache[{{{3155673600, 
       GrayLevel[0.8]}, {3155695200, 
       GrayLevel[0.8]}, {3155716800, 
       GrayLevel[0.8]}, {3155738400, 
       GrayLevel[0.8]}, {3155760000, 
       GrayLevel[0.8]}}, None}, {{{3.1556736*^9, 
       GrayLevel[0.8]}, {3.1556952*^9, 
       GrayLevel[0.8]}, {3.1557168*^9, 
       GrayLevel[0.8]}, {3.1557384*^9, 
       GrayLevel[0.8]}, {3.15576*^9, 
       GrayLevel[0.8]}}, None}],
  PlotLabel->FormBox["\"Kp\"", TraditionalForm],
  PlotRange->{{3.1556736*^9, 3.1557564*^9}, {3., 5.3}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->None]], "Output",
 CellChangeTimes->{{3.552963412790277*^9, 3.552963448393012*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DateListPlot", "[", 
  RowBox[{
   RowBox[{"results", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "3"}], "}"}]}], "]"}], "]"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<F10.7\>\""}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5529634030159883`*^9, 3.552963437451675*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, 
   {Hue[0.67, 0.6, 0.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGCQAGIQDQQOP5qeO27d3q78c/U5a5DwL1T+kd+o/La/qHyP
/6h8LsZmFP4ZJlR+HwsqP4ANlS/Egcq/wonKn8aNyo/gReVL8aPy7wig8ucJ
ofITRFD5SmKo/CfiqPxlkqj8DGlUvpYsKv+NHCp/nQISHwBCLa1Z
     "]]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  AxesOrigin->NCache[{3155673600, 0}, {3.1556736*^9, 0}],
  Frame->True,
  FrameTicks->{{Automatic, Automatic}, {{{
       NCache[3155673600, 3.1556736*^9], 
       FormBox["\"00:00\"", TraditionalForm]}, {
       NCache[3155695200, 3.1556952*^9], 
       FormBox["\"06:00\"", TraditionalForm]}, {
       NCache[3155716800, 3.1557168*^9], 
       FormBox["\"12:00\"", TraditionalForm]}, {
       NCache[3155738400, 3.1557384*^9], 
       FormBox["\"18:00\"", TraditionalForm]}, {
       NCache[3155760000, 3.15576*^9], 
       FormBox["\"00:00\"", TraditionalForm]}, {
       NCache[3155680800, 3.1556808*^9], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[3155688000, 3.155688*^9], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[3155702400, 3.1557024*^9], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[3155709600, 3.1557096*^9], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[3155724000, 3.155724*^9], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[3155731200, 3.1557312*^9], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[3155745600, 3.1557456*^9], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[3155752800, 3.1557528*^9], 
       FormBox["\"\"", TraditionalForm]}}, {{
       NCache[3155673600, 3.1556736*^9], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[3155695200, 3.1556952*^9], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[3155716800, 3.1557168*^9], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[3155738400, 3.1557384*^9], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[3155760000, 3.15576*^9], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[3155680800, 3.1556808*^9], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[3155688000, 3.155688*^9], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[3155702400, 3.1557024*^9], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[3155709600, 3.1557096*^9], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[3155724000, 3.155724*^9], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[3155731200, 3.1557312*^9], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[3155745600, 3.1557456*^9], 
       FormBox["\"\"", TraditionalForm]}, {
       NCache[3155752800, 3.1557528*^9], 
       FormBox["\"\"", TraditionalForm]}}}},
  GridLines->NCache[{{{3155673600, 
       GrayLevel[0.8]}, {3155695200, 
       GrayLevel[0.8]}, {3155716800, 
       GrayLevel[0.8]}, {3155738400, 
       GrayLevel[0.8]}, {3155760000, 
       GrayLevel[0.8]}}, None}, {{{3.1556736*^9, 
       GrayLevel[0.8]}, {3.1556952*^9, 
       GrayLevel[0.8]}, {3.1557168*^9, 
       GrayLevel[0.8]}, {3.1557384*^9, 
       GrayLevel[0.8]}, {3.15576*^9, 
       GrayLevel[0.8]}}, None}],
  PlotLabel->FormBox["\"F10.7\"", TraditionalForm],
  PlotRange->{{3.1556736*^9, 3.1557564*^9}, {0., 2.598*^-20}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->None]], "Output",
 CellChangeTimes->{{3.5529634377958603`*^9, 3.552963448474696*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Geodetic coords of radar beam", "Section",
 CellChangeTimes->{{3.5529637145342903`*^9, 3.552963737629856*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"radarToGeodetic", "[", 
   RowBox[{"mlhServer", ",", 
    RowBox[{"{", 
     RowBox[{"42.619", ",", "288.51", ",", "0.146"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"100", ",", "45", ",", "1000"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"100", ",", "55", ",", "1000"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"100", ",", "65", ",", "1000"}], "}"}]}], "}"}]}], "]"}], "//",
   "TableForm"}]], "Input",
 CellChangeTimes->{{3.552964511480783*^9, 3.5529645574597483`*^9}, {
  3.5529645965319147`*^9, 3.5529646082739058`*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {"41.361338`", 
     RowBox[{"-", "64.012651`"}], "742.038442`"},
    {"41.645771`", 
     RowBox[{"-", "65.488196`"}], "841.794521`"},
    {"41.932738`", 
     RowBox[{"-", "67.098375`"}], "918.473216`"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.552964603770937*^9, 3.552964608980863*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Radar beam coords from geodetic", "Section",
 CellChangeTimes->{{3.552964733309092*^9, 3.552964742602437*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"geodeticToRadar", "[", 
   RowBox[{"mlhServer", ",", 
    RowBox[{"{", 
     RowBox[{"42.619", ",", "288.51", ",", "0.146"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"42", ",", "290", ",", "1000"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"42", ",", "290", ",", "2000"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"42", ",", "290", ",", "3000"}], "}"}]}], "}"}]}], "]"}], "//",
   "TableForm"}]], "Input",
 CellChangeTimes->{{3.5529651257629538`*^9, 3.5529651267907753`*^9}, {
  3.552965277720811*^9, 3.552965279359776*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {"117.704418`", "80.825093`", "1011.252383`"},
    {"116.906481`", "84.802395`", "2006.351074`"},
    {"116.270492`", "86.139493`", "3004.705956`"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.552965127907077*^9, 3.552965170304926*^9, 3.552965225305892*^9, {
   3.5529652729721127`*^9, 3.5529652801306763`*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Trace magnetic field", "Section",
 CellChangeTimes->{{3.5529671824718447`*^9, 3.552967185422409*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"traceMagneticField", "[", 
   RowBox[{"mlhServer", ",", 
    RowBox[{"{", 
     RowBox[{"2004", ",", "1", ",", "1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0.583", ",", 
        RowBox[{"-", "0.95987"}], ",", "0.269"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0.6", ",", 
        RowBox[{"-", "10."}], ",", "0.3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0.6", ",", 
        RowBox[{"-", "1."}], ",", "0.3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0.6", ",", 
        RowBox[{"-", "10."}], ",", "0.3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0.6", ",", 
        RowBox[{"-", "1."}], ",", "0.3"}], "}"}]}], "}"}], ",", 
    RowBox[{"\"\<InCoordinates\>\"", "\[Rule]", "\"\<GSM\>\""}], ",", 
    RowBox[{"\"\<OutCoordinates\>\"", "\[Rule]", "\"\<Geodetic\>\""}], ",", 
    RowBox[{"\"\<TargetLocation\>\"", "\[Rule]", "\"\<NorthAlt\>\""}], ",", 
    RowBox[{"\"\<StopAlt\>\"", "\[Rule]", "1000.000000"}]}], "]"}], "//", 
  "TableForm"}]], "Input",
 CellChangeTimes->{{3.552967548039716*^9, 3.552967548041439*^9}, 
   3.552967635265411*^9, {3.552967737728341*^9, 3.552967745636004*^9}, {
   3.5529679452338667`*^9, 3.552967946406459*^9}, {3.552968226201522*^9, 
   3.5529682487769203`*^9}, {3.5529684218663197`*^9, 3.552968423742882*^9}, {
   3.552968613817308*^9, 3.5529686301215076`*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     RowBox[{"Missing", "[", "]"}], 
     RowBox[{"Missing", "[", "]"}], 
     RowBox[{"Missing", "[", "]"}]},
    {"1000.`", "74.691608`", "102.005302`"},
    {"1000.`", "19.026771`", "129.44524`"},
    {"1000.`", "74.691608`", "102.005302`"},
    {"1000.`", "19.026771`", "129.44524`"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.552968416899143*^9, 3.552968431042097*^9}, 
   3.552968590794548*^9, {3.552968621646494*^9, 3.552968637266313*^9}}]
}, Open  ]]
}, Closed]]
},
WindowSize->{1280, 752},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"8.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (February 23, \
2011)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 92, 1, 87, "Section"],
Cell[674, 25, 143, 2, 34, "Input"],
Cell[820, 29, 520, 15, 73, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[1377, 49, 95, 1, 46, "Section"],
Cell[1475, 52, 269, 5, 34, "Input"],
Cell[1747, 59, 141, 1, 33, "Text"],
Cell[CellGroupData[{
Cell[1913, 64, 539, 13, 34, "Input"],
Cell[2455, 79, 1933, 44, 417, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[4437, 129, 96, 1, 46, "Section"],
Cell[4536, 132, 153, 3, 33, "Text"],
Cell[4692, 137, 837, 17, 34, "Input"],
Cell[5532, 156, 396, 10, 34, "Input"],
Cell[5931, 168, 238, 5, 33, "Text"],
Cell[CellGroupData[{
Cell[6194, 177, 521, 11, 34, "Input"],
Cell[6718, 190, 136, 3, 34, "Output"]
}, Open  ]],
Cell[6869, 196, 360, 7, 33, "Text"],
Cell[7232, 205, 424, 10, 34, "Input"],
Cell[CellGroupData[{
Cell[7681, 219, 1172, 29, 73, "Input"],
Cell[8856, 250, 23710, 509, 281, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[32615, 765, 105, 1, 46, "Section"],
Cell[32723, 768, 132, 2, 34, "Input"],
Cell[32858, 772, 373, 7, 34, "Input"],
Cell[CellGroupData[{
Cell[33256, 783, 182, 4, 34, "Input"],
Cell[33441, 789, 1217, 35, 162, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[34695, 829, 366, 8, 34, "Input"],
Cell[35064, 839, 1209, 36, 162, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[36322, 881, 148, 2, 46, "Section"],
Cell[36473, 885, 132, 2, 34, "Input"],
Cell[36608, 889, 360, 9, 34, "Input"],
Cell[CellGroupData[{
Cell[36993, 902, 152, 3, 34, "Input"],
Cell[37148, 907, 656, 14, 54, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[37853, 927, 91, 1, 46, "Section"],
Cell[37947, 930, 585, 10, 52, "Text"],
Cell[38535, 942, 227, 6, 34, "Input"],
Cell[38765, 950, 722, 15, 54, "Input"],
Cell[CellGroupData[{
Cell[39512, 969, 122, 2, 34, "Input"],
Cell[39637, 973, 74, 1, 34, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[39748, 979, 585, 16, 34, "Input"],
Cell[40336, 997, 43959, 735, 340, 21354, 362, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[84332, 1737, 756, 20, 54, "Input"],
Cell[85091, 1759, 14178, 242, 312, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[99318, 2007, 106, 1, 46, "Section"],
Cell[CellGroupData[{
Cell[99449, 2012, 829, 19, 54, "Input"],
Cell[100281, 2033, 1438, 35, 256, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[101768, 2074, 153, 2, 46, "Section"],
Cell[101924, 2078, 928, 20, 34, "Input"],
Cell[CellGroupData[{
Cell[102877, 2102, 174, 4, 34, "Input"],
Cell[103054, 2108, 493, 13, 43, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[103584, 2126, 346, 9, 34, "Input"],
Cell[103933, 2137, 3462, 82, 345, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[107432, 2224, 349, 9, 34, "Input"],
Cell[107784, 2235, 3435, 81, 317, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[111268, 2322, 116, 1, 46, "Section"],
Cell[CellGroupData[{
Cell[111409, 2327, 615, 16, 54, "Input"],
Cell[112027, 2345, 778, 21, 76, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[112854, 2372, 116, 1, 46, "Section"],
Cell[CellGroupData[{
Cell[112995, 2377, 613, 16, 54, "Input"],
Cell[113611, 2395, 798, 20, 76, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[114458, 2421, 107, 1, 46, "Section"],
Cell[CellGroupData[{
Cell[114590, 2426, 1406, 32, 92, "Input"],
Cell[115999, 2460, 935, 24, 116, "Output"]
}, Open  ]]
}, Closed]]
}
]
*)

(* End of internal cache information *)
